@@ -1,10 +1,10 @@
 from sdk.device.configuration.base_config import BaseConfig, InvalidConfiguration
 from sdk.device.configuration.emu_free import EmuFreeConfig
-from sdk.device.configuration.emu_sv import EmuSVConfig
+from sdk.device.configuration.emu_tn import EmuTNConfig
 
 __all__ = [
     "BaseConfig",
     "InvalidConfiguration",
     "EmuFreeConfig",
-    "EmuSVConfig",
+    "EmuTNConfig",
 ]
