@@ -12,9 +12,10 @@ class Job:
         - updated_at: Timestamps of the last update of the batch.
         - start_timestamp(optional): The timestamp of when the job began processing.
         - end_timestamp(optional): The timestamp of when the job finished processing.
-        - batch_id: Id of the batch which the job belongs to.
+        - batch_id: ID of the batch which the job belongs to.
         - errors: Error messages that occured while processing job.
         - id: Unique identifier for the batch
+        - group_id: ID of the group which the users scheduling the job belong to.
         - status: Status of the job
         - result(optional): Result of the job.
         - variables (optional): dictionnary of variables of the job.
@@ -24,6 +25,7 @@ class Job:
     runs: int
     batch_id: str
     id: str
+    group_id: str
     status: str
     created_at: str
     updated_at: str
